==> ToolChain_STM32_1.0.45.tar.bz: ToolChain_STM32_1.0.45/CommonLibraries/stm32/stm32_gpio.h <==
#ifndef STM32_GPIO_H
#define STM32_GPIO_H

/*{ stm32_gpio.h ***********************************************
 
 * Written by Gregor Rebel 2010-2012
 *
 * Low Level Driver for General Purpose Input Output (GPIO) on STM32 architecture.
 * 
}*/
//{ includes1

#include "ttc_basic.h"
#include "stm32f10x_gpio.h"

//}includes
//{ Structures/ Enums

typedef struct { // stm32_Port_t
    GPIO_TypeDef* GPIOx;
    u8_t Pin;
} __attribute__((__packed__)) stm32_Port_t;

//}Structures/ Enums
//{ Architecture-Defines (required by ttc_gpio_types.h)

#define ttc_GPIO_BANK  GPIO_TypeDef*
#define ttc_Port_t     stm32_Port_t

//{ Define shortcuts for all pins of GPIO Bank A
#define PIN_PA0  GPIOA,0
#define PIN_PA1  GPIOA,1
#define PIN_PA2  GPIOA,2
#define PIN_PA3  GPIOA,3
#define PIN_PA4  GPIOA,4
#define PIN_PA5  GPIOA,5
#define PIN_PA6  GPIOA,6
#define PIN_PA7  GPIOA,7
#define PIN_PA8  GPIOA,8
#define PIN_PA9  GPIOA,9
#define PIN_PA10 GPIOA,10
#define PIN_PA11 GPIOA,11
#define PIN_PA12 GPIOA,12
#define PIN_PA13 GPIOA,13
#define PIN_PA14 GPIOA,14
#define PIN_PA15 GPIOA,15
//}BankA
//{ Define shortcuts for all pins of GPIO Bank B
#define PIN_PB0  GPIOB,0
#define PIN_PB1  GPIOB,1
#define PIN_PB2  GPIOB,2
#define PIN_PB3  GPIOB,3
#define PIN_PB4  GPIOB,4
#define PIN_PB5  GPIOB,5
#define PIN_PB6  GPIOB,6
#define PIN_PB7  GPIOB,7
#define PIN_PB8  GPIOB,8
#define PIN_PB9  GPIOB,9
#define PIN_PB10 GPIOB,10
#define PIN_PB11 GPIOB,11
#define PIN_PB12 GPIOB,12
#define PIN_PB13 GPIOB,13
#define PIN_PB14 GPIOB,14
#define PIN_PB15 GPIOB,15
//}BankB
//{ Define shortcuts for all pins of GPIO Bank C
#define PIN_PC0  GPIOC,0
#define PIN_PC1  GPIOC,1
#define PIN_PC2  GPIOC,2
#define PIN_PC3  GPIOC,3
#define PIN_PC4  GPIOC,4
#define PIN_PC5  GPIOC,5
#define PIN_PC6  GPIOC,6
#define PIN_PC7  GPIOC,7
#define PIN_PC8  GPIOC,8
#define PIN_PC9  GPIOC,9
#define PIN_PC10 GPIOC,10
#define PIN_PC11 GPIOC,11
#define PIN_PC12 GPIOC,12
#define PIN_PC13 GPIOC,13
#define PIN_PC14 GPIOC,14
#define PIN_PC15 GPIOC,15
//}BankC
//{ Define shortcuts for all pins of GPIO Bank D
#define PIN_PD0  GPIOD,0
#define PIN_PD1  GPIOD,1
#define PIN_PD2  GPIOD,2
#define PIN_PD3  GPIOD,3
#define PIN_PD4  GPIOD,4
#define PIN_PD5  GPIOD,5
#define PIN_PD6  GPIOD,6
#define PIN_PD7  GPIOD,7
#define PIN_PD8  GPIOD,8
#define PIN_PD9  GPIOD,9
#define PIN_PD10 GPIOD,10
#define PIN_PD11 GPIOD,11
#define PIN_PD12 GPIOD,12
#define PIN_PD13 GPIOD,13
#define PIN_PD14 GPIOD,14
#define PIN_PD15 GPIOD,15
//}BankD
//{ Define shortcuts for all pins of GPIO Bank E
#define PIN_PE0  GPIOE,0
#define PIN_PE1  GPIOE,1
#define PIN_PE2  GPIOE,2
#define PIN_PE3  GPIOE,3
#define PIN_PE4  GPIOE,4
#define PIN_PE5  GPIOE,5
#define PIN_PE6  GPIOE,6
#define PIN_PE7  GPIOE,7
#define PIN_PE8  GPIOE,8
#define PIN_PE9  GPIOE,9
#define PIN_PE10 GPIOE,10
#define PIN_PE11 GPIOE,11
#define PIN_PE12 GPIOE,12
#define PIN_PE13 GPIOE,13
#define PIN_PE14 GPIOE,14
#define PIN_PE15 GPIOE,15
//}BankE
//{ Define shortcuts for all pins of GPIO Bank F
#define PIN_PF0  GPIOF,0
#define PIN_PF1  GPIOF,1
#define PIN_PF2  GPIOF,2
#define PIN_PF3  GPIOF,3
#define PIN_PF4  GPIOF,4
#define PIN_PF5  GPIOF,5
#define PIN_PF6  GPIOF,6
#define PIN_PF7  GPIOF,7
#define PIN_PF8  GPIOF,8
#define PIN_PF9  GPIOF,9
#define PIN_PF10 GPIOF,10
#define PIN_PF11 GPIOF,11
#define PIN_PF12 GPIOF,12
#define PIN_PF13 GPIOF,13
#define PIN_PF14 GPIOF,14
#define PIN_PF15 GPIOF,15
//}BankF

//}Defines
//{ includes2

#include "ttc_gpio_types.h"  // must be included AFTER defining some ttc_XXXX thingies
#include <stdlib.h>
#include "stm32f10x.h"
#include "core_cm3.h"
#include "stm32f10x_conf.h"
#include "stm32f10x_gpio.h"

// FreeRTOS
#include <string.h>
#include "stddef.h"

//}includes2
//{ Prototypes

/* converts from architecture independent pin type to stm32 pendant
 * @param    Type   one of tgm_analog_in, tgm_input_floating, tgm_input_pull_down, tgm_input_pull_up, tgm_output_open_drain, tgm_output_push_pull, tgm_alternate_function_push_pull, tgm_alternate_function_open_drain
 * @return   one of GPIO_Mode_AIN, GPIO_Mode_IN_FLOATING, GPIO_Mode_IPD, GPIO_Mode_IPU, GPIO_Mode_Out_OD, GPIO_Mode_Out_PP, GPIO_Mode_Out_OD, GPIO_Mode_AF_PP, GPIO_Mode_AF_OD
 */
GPIOMode_TypeDef stm32_map_Type(ttc_gpio_mode_e Type);

/* converts from architecture independent pin speed to stm32 pendant
 * @param    Type   one of tgs_Min, tgs_2MHz, tgs_10MHz, tgs_50MHz, tgs_Max
 * @return   one of GPIO_Speed_2MHz, GPIO_Speed_10MHz, GPIO_Speed_50MHz
 */
GPIOSpeed_TypeDef stm32_map_Speed(ttc_gpio_speed_e Speed);

/* initializes single port bit for use as input/ output
 * @param Port  filled out struct as being returned by stm32_loadPort()
 * @param Type   one of GPIO_Mode_AIN, GPIO_Mode_IN_FLOATING, GPIO_Mode_IPD, GPIO_Mode_IPU, GPIO_Mode_Out_OD, GPIO_Mode_Out_PP, GPIO_Mode_Out_OD, GPIO_Mode_AF_PP, GPIO_Mode_AF_OD
 * @param Speed  one of GPIO_Speed_2MHz, GPIO_Speed_10MHz, GPIO_Speed_50MHz
 */
void stm32_initPort2(stm32_Port_t* Port, GPIOMode_TypeDef Type, GPIOSpeed_TypeDef Speed);

/* allows to load struct from list type definition
 *
 * @param Port   points to structure to be filled with given data
 * @param GPIOx  one of GPIOA, GPIOB, GPIOC, GPIOD, GPIOE, GPIOF
 * @param Pin    0..15
 *
 * Example:
 * #define PB_LED1=GPIOC,6
 * stm32_Port_t Port;
 * stm32_loadPort(&Port, PB_LED1);
 * stm32_initPort(&Port, GPIO_Mode_Out_PP);
 * stm32_portSet(&Port);
 */
void stm32_loadPort(stm32_Port_t* Port, GPIO_TypeDef* GPIOx, u32_t Pin);

/* read current value of input pin
 * @param Port  filled out struct as being returned by stm32_loadPort()
 */
bool stm32_portGet(stm32_Port_t* Port);

/* set output pin to logical one
 * @param Port  filled out struct as being returned by stm32_loadPort()
 */
void stm32_portSet(stm32_Port_t* Port);

/* set output pin to logical zero
 * @param Port  filled out struct as being returned by stm32_loadPort()
 */
void stm32_portClr(stm32_Port_t* Port);

//} Prototypes

#endif

==> ToolChain_STM32_1.0.49.tar.bz: ToolChain_STM32_1.0.49/CommonLibraries/stm32/stm32_gpio.h <==
#ifndef STM32_GPIO_H
#define STM32_GPIO_H

/*{ stm32_gpio.h ***********************************************
 
 * Written by Gregor Rebel 2010-2012
 *
 * Low Level Driver for General Purpose Input Output (GPIO) on STM32 architecture.
 * 
}*/
//{ includes1

#ifndef EXTENSION_250_stm_std_peripherals
  #error EXTENSION_250_stm_std_peripherals not defined -> activate.200_cpu_stm32f10x_std_peripherals.sh
#endif

#include "ttc_basic.h"
#include "stm32f10x_gpio.h"
#include "stm32f10x_rcc.h"

//}includes
//{ Structures/ Enums

typedef struct { // stm32_Port_t
    GPIO_TypeDef* GPIOx;
    u8_t Pin;
    volatile u32_t* BSRR;  // bit-band address of BSRR register of this port bit
    volatile u32_t* BRR;   // bit-band address of BRR register of this port bit
    volatile u32_t* IDR;   // bit-band address of IDR register of this port bit
} __attribute__((__packed__)) stm32_Port_t;

//}Structures/ Enums
//{ Architecture-Defines (required by ttc_gpio_types.h)

// amount of gpio banks (A..G)
#define TTC_GPIO_MAX_AMOUNT 7

// amount of port pins per bank
#define TTC_GPIO_MAX_PINS 16

#define ttc_GPIO_BANK  GPIO_TypeDef*
#define ttc_Port_t     stm32_Port_t

//{ Define shortcuts for all pins of GPIO Bank A
#define PIN_PA0  GPIOA,0
#define PIN_PA1  GPIOA,1
#define PIN_PA2  GPIOA,2
#define PIN_PA3  GPIOA,3
#define PIN_PA4  GPIOA,4
#define PIN_PA5  GPIOA,5
#define PIN_PA6  GPIOA,6
#define PIN_PA7  GPIOA,7
#define PIN_PA8  GPIOA,8
#define PIN_PA9  GPIOA,9
#define PIN_PA10 GPIOA,10
#define PIN_PA11 GPIOA,11
#define PIN_PA12 GPIOA,12
#define PIN_PA13 GPIOA,13
#define PIN_PA14 GPIOA,14
#define PIN_PA15 GPIOA,15
//}BankA
//{ Define shortcuts for all pins of GPIO Bank B
#define PIN_PB0  GPIOB,0
#define PIN_PB1  GPIOB,1
#define PIN_PB2  GPIOB,2
#define PIN_PB3  GPIOB,3
#define PIN_PB4  GPIOB,4
#define PIN_PB5  GPIOB,5
#define PIN_PB6  GPIOB,6
#define PIN_PB7  GPIOB,7
#define PIN_PB8  GPIOB,8
#define PIN_PB9  GPIOB,9
#define PIN_PB10 GPIOB,10
#define PIN_PB11 GPIOB,11
#define PIN_PB12 GPIOB,12
#define PIN_PB13 GPIOB,13
#define PIN_PB14 GPIOB,14
#define PIN_PB15 GPIOB,15
//}BankB
//{ Define shortcuts for all pins of GPIO Bank C
#define PIN_PC0  GPIOC,0
#define PIN_PC1  GPIOC,1
#define PIN_PC2  GPIOC,2
#define PIN_PC3  GPIOC,3
#define PIN_PC4  GPIOC,4
#define PIN_PC5  GPIOC,5
#define PIN_PC6  GPIOC,6
#define PIN_PC7  GPIOC,7
#define PIN_PC8  GPIOC,8
#define PIN_PC9  GPIOC,9
#define PIN_PC10 GPIOC,10
#define PIN_PC11 GPIOC,11
#define PIN_PC12 GPIOC,12
#define PIN_PC13 GPIOC,13
#define PIN_PC14 GPIOC,14
#define PIN_PC15 GPIOC,15
//}BankC
//{ Define shortcuts for all pins of GPIO Bank D
#define PIN_PD0  GPIOD,0
#define PIN_PD1  GPIOD,1
#define PIN_PD2  GPIOD,2
#define PIN_PD3  GPIOD,3
#define PIN_PD4  GPIOD,4
#define PIN_PD5  GPIOD,5
#define PIN_PD6  GPIOD,6
#define PIN_PD7  GPIOD,7
#define PIN_PD8  GPIOD,8
#define PIN_PD9  GPIOD,9
#define PIN_PD10 GPIOD,10
#define PIN_PD11 GPIOD,11
#define PIN_PD12 GPIOD,12
#define PIN_PD13 GPIOD,13
#define PIN_PD14 GPIOD,14
#define PIN_PD15 GPIOD,15
//}BankD
//{ Define shortcuts for all pins of GPIO Bank E
#define PIN_PE0  GPIOE,0
#define PIN_PE1  GPIOE,1
#define PIN_PE2  GPIOE,2
#define PIN_PE3  GPIOE,3
#define PIN_PE4  GPIOE,4
#define PIN_PE5  GPIOE,5
#define PIN_PE6  GPIOE,6
#define PIN_PE7  GPIOE,7
#define PIN_PE8  GPIOE,8
#define PIN_PE9  GPIOE,9
#define PIN_PE10 GPIOE,10
#define PIN_PE11 GPIOE,11
#define PIN_PE12 GPIOE,12
#define PIN_PE13 GPIOE,13
#define PIN_PE14 GPIOE,14
#define PIN_PE15 GPIOE,15
//}BankE
//{ Define shortcuts for all pins of GPIO Bank F
#define PIN_PF0  GPIOF,0
#define PIN_PF1  GPIOF,1
#define PIN_PF2  GPIOF,2
#define PIN_PF3  GPIOF,3
#define PIN_PF4  GPIOF,4
#define PIN_PF5  GPIOF,5
#define PIN_PF6  GPIOF,6
#define PIN_PF7  GPIOF,7
#define PIN_PF8  GPIOF,8
#define PIN_PF9  GPIOF,9
#define PIN_PF10 GPIOF,10
#define PIN_PF11 GPIOF,11
#define PIN_PF12 GPIOF,12
#define PIN_PF13 GPIOF,13
#define PIN_PF14 GPIOF,14
#define PIN_PF15 GPIOF,15
//}BankF

//}Defines
//{ includes2

#include "ttc_gpio_types.h"  // must be included AFTER defining some ttc_XXXX thingies
//X #include <stdlib.h>
#include "stm32f10x.h"
#include "core_cm3.h"
#include "stm32f10x_conf.h"
#include "stm32f10x_gpio.h"

// FreeRTOS
#include <string.h>
#include "stddef.h"

//}includes2
//{ Prototypes

/** converts from architecture independent pin type to stm32 pendant
 * @param    Type   one of tgm_analog_in, tgm_input_floating, tgm_input_pull_down, tgm_input_pull_up, tgm_output_open_drain, tgm_output_push_pull, tgm_alternate_function_push_pull, tgm_alternate_function_open_drain
 * @return   one of GPIO_Mode_AIN, GPIO_Mode_IN_FLOATING, GPIO_Mode_IPD, GPIO_Mode_IPU, GPIO_Mode_Out_OD, GPIO_Mode_Out_PP, GPIO_Mode_Out_OD, GPIO_Mode_AF_PP, GPIO_Mode_AF_OD
 */
GPIOMode_TypeDef stm32_map_Type(ttc_gpio_mode_e Type);

/** converts from architecture independent pin speed to stm32 pendant
 * @param    Type   one of tgs_Min, tgs_2MHz, tgs_10MHz, tgs_50MHz, tgs_Max
 * @return   one of GPIO_Speed_2MHz, GPIO_Speed_10MHz, GPIO_Speed_50MHz
 */
GPIOSpeed_TypeDef stm32_map_Speed(ttc_gpio_speed_e Speed);

/** initializes single port bit for use as input/ output
 * @param Port  filled out struct as being returned by stm32_gpio_variable()
 * @param Type   one of GPIO_Mode_AIN, GPIO_Mode_IN_FLOATING, GPIO_Mode_IPD, GPIO_Mode_IPU, GPIO_Mode_Out_OD, GPIO_Mode_Out_PP, GPIO_Mode_Out_OD, GPIO_Mode_AF_PP, GPIO_Mode_AF_OD
 * @param Speed  one of GPIO_Speed_2MHz, GPIO_Speed_10MHz, GPIO_Speed_50MHz
 */
void stm32_gpio_init_variable(stm32_Port_t* Port, GPIOMode_TypeDef Type, GPIOSpeed_TypeDef Speed);

/** initializes single port bit for use as input/ output
 * @param GPIOx  one of GPIOA, GPIOB, GPIOC, GPIOD, GPIOE, GPIOF
 * @param Pin    0..15
 * @param Type   one of GPIO_Mode_AIN, GPIO_Mode_IN_FLOATING, GPIO_Mode_IPD, GPIO_Mode_IPU, GPIO_Mode_Out_OD, GPIO_Mode_Out_PP, GPIO_Mode_Out_OD, GPIO_Mode_AF_PP, GPIO_Mode_AF_OD
 * @param Speed  one of GPIO_Speed_2MHz, GPIO_Speed_10MHz, GPIO_Speed_50MHz
 */
void stm32_gpio_init(GPIO_TypeDef* GPIOx, u8_t Pin, GPIOMode_TypeDef Type, GPIOSpeed_TypeDef Speed);

/** allows to load struct from list type definition
 *
 * @param Port   points to structure to be filled with given data
 * @param GPIOx  one of GPIOA, GPIOB, GPIOC, GPIOD, GPIOE, GPIOF
 * @param Pin    0..15
 *
 * Example:
 * #define PB_LED1=GPIOC,6
 * stm32_Port_t Port;
 * stm32_gpio_variable(&Port, PB_LED1);
 * stm32_gpio_init_variable(&Port, GPIO_Mode_Out_PP);
 * stm32_gpio_set_variable(&Port);
 */
void stm32_gpio_variable(stm32_Port_t* Port, GPIO_TypeDef* GPIOx, u8_t Pin);

/** read current value of input pin
 * @param Port  filled out struct as being returned by stm32_gpio_variable()
 */
bool stm32_gpio_get_variable(stm32_Port_t* Port);

/** set output pin to logical one
 * @param Port  filled out struct as being returned by stm32_gpio_variable()
 */
void stm32_gpio_set_variable(stm32_Port_t* Port);

/** set output pin to logical zero
 * @param Port  filled out struct as being returned by stm32_gpio_variable()
 */
void stm32_gpio_clr_variable(stm32_Port_t* Port);

/** read current value of input pin
 * @param GPIOx  one of GPIOA, GPIOB, GPIOC, GPIOD, GPIOE, GPIOF
 * @param Pin    0..15
 */
bool stm32_gpio_get(GPIO_TypeDef* GPIOx, u8_t Pin);

/** set output pin to logical one
 * @param GPIOx  one of GPIOA, GPIOB, GPIOC, GPIOD, GPIOE, GPIOF
 * @param Pin    0..15
 */
void stm32_gpio_clr(GPIO_TypeDef* GPIOx, u8_t Pin);

/** set output pin to logical zero
 * @param GPIOx  one of GPIOA, GPIOB, GPIOC, GPIOD, GPIOE, GPIOF
 * @param Pin    0..15
 */
void stm32_gpio_set(GPIO_TypeDef* GPIOx, u8_t Pin);

/** Calculate bit-banding address that corresponds to given bit in given 32-bit word
 *
 * @param   PeripheralWord   address of 32-bit word in which desired bit is located
 * @param   BitNumber        0..31
 * @return  address in peripheral bit-banding region that corresponds to given word and bit-number
 */
volatile u32_t* stm32_calc_peripheral_BitBandAddress(void* PeripheralWord, u8_t BitNumber);

/** creates numeric 8-bit representing given GPIO-bank and pin number
 *
 * @param GPIOx  GPIO bank to use (-> ttc_gpio_types.h:ttc_GPIO_BANK)
 *               Note: GPIOx, Pin can be given as one argument by use of Pin_Pxn macro (GPIOA, 7) = Pin_PA7
 * @param Pin    0..15
 * @return       8-bit value representing given GPIO-pin in a memory friendly format
 */
u8_t stm32_gpio_create_index8(ttc_GPIO_BANK GPIOx, u8_t Pin);

/** restores GPIO-bank and pin number from 8-bit value
 *
 * @param PhysicalIndex  8-bit value representing GPIO-bank + pin
 * @param GPIOx          loaded with GPIO bank (-> ttc_gpio_types.h:ttc_GPIO_BANK)
 * @param Pin            loaded with pin number
 */
void stm32_gpio_from_index8(u8_t PhysicalIndex, GPIO_TypeDef** GPIOx, u8_t* Pin);

//} Prototypes

#endif
